summaryrefslogtreecommitdiff
path: root/lisp/net/newst-backend.el
diff options
context:
space:
mode:
authorUlf Jasper <ulf.jasper@web.de>2014-11-27 19:32:08 +0100
committerUlf Jasper <ulf.jasper@web.de>2014-11-27 19:32:08 +0100
commitcceb7a8921e34d4b4942456b59d342a7566fda59 (patch)
treeb7a3d92cacbd017f55d9e352ed675d48eb64b19b /lisp/net/newst-backend.el
parent07efa3f0ba196c1eea130032c765d5d1a62fa627 (diff)
downloademacs-cceb7a8921e34d4b4942456b59d342a7566fda59.tar.gz
newsticker: Handle embedded (x)html in atom feeds.
* lisp/net/newst-backend.el (newsticker--parse-atom-1.0): Handle embedded (x)html in summary node.
Diffstat (limited to 'lisp/net/newst-backend.el')
-rw-r--r--lisp/net/newst-backend.el14
1 files changed, 9 insertions, 5 deletions
diff --git a/lisp/net/newst-backend.el b/lisp/net/newst-backend.el
index 41f8b8440bd..31ebc7ac583 100644
--- a/lisp/net/newst-backend.el
+++ b/lisp/net/newst-backend.el
@@ -1216,13 +1216,17 @@ URL `http://www.atompub.org/2005/08/17/draft-ietf-atompub-format-11.html'"
(car (xml-get-children node 'title)))))
;; desc-fn
(lambda (node)
;; unxml the content node. Atom allows for
;; integrating (x)html into the atom structure
;; but we need the raw html string.
;; e.g. http://www.heise.de/open/news/news-atom.xml
- (or (newsticker--unxml
+ ;; http://feeds.feedburner.com/ru_nix_blogs
+ (or (newsticker--unxml
(car (xml-node-children
- (car (xml-get-children node 'content)))))
+ (car (xml-get-children node 'content)))))
+ (newsticker--unxml
+ (car (xml-node-children
+ (car (xml-get-children node 'summary)))))
(car (xml-node-children
(car (xml-get-children node 'summary))))))
;; link-fn
@@ -1216,13 +1216,17 @@ URL `http://www.atompub.org/2005/08/17/draft-ietf-atompub-format-11.html'"
;; desc-fn
(lambda (node)
- ;; unxml the content node. Atom allows for
- ;; integrating (x)html into the atom structure
- ;; but we need the raw html string.
+ ;; unxml the content or the summary node. Atom
+ ;; allows for integrating (x)html into the atom
+ ;; structure but we need the raw html string.
;; e.g. http://www.heise.de/open/news/news-atom.xml